#!/usr/bin/env python

# author: Pocholo
# date: 1/18/21

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugins folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.


from gimpfu import *

def pm_carved_plastic_or_chrome_text(customtext, fontname, plastic, chrome, size):
	
	if plastic:
	
		#Create new image
		img = pdb.gimp_image_new(1, 1, RGB)
		
		#Variables
		width = img.width
		height = img.height
		
		pdb.gimp_context_set_defaults()
		pdb.gimp_context_set_default_colors()
		
		#Create the text	
		pdb.gimp_context_set_foreground((0, 0, 0))
		textLayer = pdb.gimp_text_fontname(img, None, 0, 0, customtext, 200, 1, size, PIXELS, fontname)
		pdb.gimp_text_layer_set_justification(textLayer, TEXT_JUSTIFY_CENTER)
		pdb.gimp_text_layer_set_line_spacing(textLayer, 75)
		pdb.gimp_text_layer_set_letter_spacing(textLayer, 50)
			
		#Resize text
		img.resize(textLayer.width, textLayer.height, 0, 0)
		
		#Making the text centered	
		textLayer = pdb.gimp_image_get_active_layer(img)
		pdb.gimp_image_set_active_layer(img, textLayer)
		wh = pdb.gimp_drawable_width(textLayer)
		hh = pdb.gimp_drawable_height(textLayer)
		w = pdb.gimp_image_width(img)
		h = pdb.gimp_image_height(img)
		pdb.gimp_image_set_active_layer(img,textLayer)
		centerx=w/2
		centery=h/2
		adw=wh/2
		adh=hh/2
		sw=centerx - adw
		sh=centery - adh		
		pdb.gimp_layer_set_offsets(textLayer, sw, sh)
		pdb.gimp_selection_none(img)
			
		#Create the first paper layer Background
		paper1Layer = pdb.gimp_layer_new(img, img.width, img.height, RGB, "Paper #1", 100, LAYER_MODE_NORMAL)
		pdb.gimp_layer_add_alpha(paper1Layer)
		pdb.gimp_image_add_layer(img, paper1Layer, 1)
		pdb.gimp_context_set_foreground((174, 174, 174))
		pdb.gimp_drawable_fill(paper1Layer, FILL_FOREGROUND)		
		pdb.gimp_display_new(img)

		#Create paper 2 layer
		paper2Layer = pdb.gimp_layer_new(img, img.width, img.height, RGB, "Paper #2", 100, LAYER_MODE_NORMAL)
		pdb.gimp_layer_add_alpha(paper2Layer)
		pdb.gimp_image_add_layer(img, paper2Layer, 1)
		pdb.gimp_context_set_foreground((217, 217, 217))
		pdb.gimp_drawable_fill(paper2Layer, FILL_FOREGROUND)	
		pdb.plug_in_hsv_noise(img, paper2Layer, 8, 3, 4, 75)
		pdb.plug_in_gauss(img, paper2Layer, 1.5, 1.5, 1)
		
		#Create paper 3 layer
		pdb.gimp_context_set_foreground((234, 234, 234))
		paper3Layer = pdb.gimp_layer_new(img, img.width, img.height, RGB, "Paper #3", 0, LAYER_MODE_NORMAL)
		pdb.gimp_layer_add_alpha(paper3Layer)
		pdb.gimp_image_add_layer(img, paper3Layer, 1)
		pdb.gimp_drawable_fill(paper3Layer, FILL_FOREGROUND)	
		pdb.plug_in_hsv_noise(img, paper3Layer, 8, 3, 4, 75)
		pdb.plug_in_gauss(img, paper3Layer, 1.5, 1.5, 1)
		
		#Make a selection on the text
		pdb.gimp_image_select_item(img, 2, textLayer)
		pdb.gimp_selection_grow(img, 12)
		pdb.gimp_context_set_foreground((0, 0, 0))
		pdb.gimp_edit_bucket_fill(textLayer, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)	
		pdb.gimp_layer_set_opacity(textLayer, 0)
		pdb.gimp_item_set_name(textLayer, "Text")
		
		#Create first cut
		pdb.gimp_image_select_item(img, 2, textLayer)
		pdb.gimp_selection_shrink(img, 25)
		paper2Layer = pdb.gimp_image_get_layer_by_name(img, "Paper #2")
		pdb.gimp_drawable_edit_clear(paper2Layer)
		pdb.gimp_selection_none(img)
		#Drop Shadow
		pdb.python_layerfx_drop_shadow(img, paper2Layer,
											("Black"),   #color
												  100,   #opacity
													0,   #contou - linear
													0,   #noise
													3,   #mode - multiply
												   40,   #spread
												   25,   #size
												  120,   #offset_angle
													5,   #offset_distance
												  TRUE,   #knockout
												 FALSE)   #merge
				
		#Create second cut
		pdb.python_layerfx_stroke(img, textLayer, 
								 (234, 234, 234),    #color 
											   0,	 #opacity
											   0,	 #mode - normal
											 100,	 #size
											 100,	 #position
										   FALSE)	 #merge
		
		#Stroke
		stroke = pdb.gimp_image_get_layer_by_name(img, "Text-stroke")
		pdb.gimp_image_select_item(img, 2, stroke)
		pdb.gimp_selection_shrink(img, 10)
		pdb.gimp_selection_feather(img, 35)
		pdb.gimp_selection_sharpen(img)
		pdb.gimp_drawable_edit_clear(paper3Layer)
		pdb.gimp_selection_none(img)
		
		#Drop Shadow
		pdb.python_layerfx_drop_shadow(img, paper3Layer,
											  ("Black"),   #color
													100,   #opacity
													  0,   #contou - linear
													  0,   #noise
													  3,   #mode - multiply
													 40,   #spread
													 25,   #size
													120,   #offset_angle
													  5,   #offset_distance
												   TRUE,   #knockout
												 FALSE)   #merge
		
		
		#Bevel and emboss
		pdb.python_layerfx_bevel_emboss(img, paper3Layer, 
														 1,   #style inner bevel
														65,   #depth 
														 0,   #direction 
														20,   #size 
														16,   #soften
													   120,   #angle 
														30,   #altitude 
														 0,   #gloss_contour - linear
												   "White",   #highlight_color 
														 5,   #highlight_mode lighten only
														75,   #highlight_opacity
												   "Black",   #shadow_color 
														 3,   #shadow_mode - multiply
														75,   #shadow_opacity 
														 0,   #surface_contour - linear
													 FALSE,   #use_texture 
											   "Dried mud",   #pattern 
													   100,   #scale 
													   100,   #tex_depth 
													 FALSE,   #invert 
													 FALSE)   #merge	
			
		#Bevel and emboss
		pdb.python_layerfx_bevel_emboss(img, textLayer, 
													 1,   #style inner bevel
													65,   #depth 
													 0,   #direction 
													20,   #size 
													16,   #soften
												   120,   #angle 
													30,   #altitude 
													 0,   #gloss_contour - linear
											   "White",   #highlight_color 
													 5,   #highlight_mode lighten only
													75,   #highlight_opacity
											   "Black",   #shadow_color 
													 3,   #shadow_mode - multiply
													75,   #shadow_opacity 
													 0,   #surface_contour - linear
												 FALSE,   #use_texture 
										   "Dried mud",   #pattern 
												   100,   #scale 
												   100,   #tex_depth 
												 FALSE,   #invert 
												 FALSE)   #merge
		
		#Make one layer and rename	
		text = pdb.gimp_image_flatten(img)
		text = pdb.gimp_image_get_layer_by_name(img, "Paper #1")
		pdb.gimp_item_set_name(text, "Carved Plastic Text")
		
	
	if chrome:
		#Create new image
		img = pdb.gimp_image_new(1, 1, RGB)
		
		#Variables
		width = img.width
		height = img.height
		
		pdb.gimp_context_set_defaults()
		pdb.gimp_context_set_default_colors()
		
		#Create the text	
		pdb.gimp_context_set_foreground((0, 0, 0))
		textLayer = pdb.gimp_text_fontname(img, None, 0, 0, customtext, 200, 1, size, PIXELS, fontname)
		pdb.gimp_text_layer_set_justification(textLayer, TEXT_JUSTIFY_CENTER)
		pdb.gimp_text_layer_set_line_spacing(textLayer, 75)
		pdb.gimp_text_layer_set_letter_spacing(textLayer, 50)
			
		#Resize text
		img.resize(textLayer.width, textLayer.height, 0, 0)
		
		#Making the text centered	
		textLayer = pdb.gimp_image_get_active_layer(img)
		pdb.gimp_image_set_active_layer(img, textLayer)
		wh = pdb.gimp_drawable_width(textLayer)
		hh = pdb.gimp_drawable_height(textLayer)
		w = pdb.gimp_image_width(img)
		h = pdb.gimp_image_height(img)
		pdb.gimp_image_set_active_layer(img,textLayer)
		centerx=w/2
		centery=h/2
		adw=wh/2
		adh=hh/2
		sw=centerx - adw
		sh=centery - adh		
		pdb.gimp_layer_set_offsets(textLayer, sw, sh)
		pdb.gimp_selection_none(img)
			
		#Create the first paper layer Background
		paper1Layer = pdb.gimp_layer_new(img, img.width, img.height, RGB, "Paper #1", 100, LAYER_MODE_NORMAL)
		pdb.gimp_layer_add_alpha(paper1Layer)
		pdb.gimp_image_add_layer(img, paper1Layer, 1)
		pdb.gimp_context_set_foreground((174, 174, 174))
		pdb.gimp_drawable_fill(paper1Layer, FILL_FOREGROUND)		
		pdb.gimp_display_new(img)

		#Create paper 2 layer
		paper2Layer = pdb.gimp_layer_new(img, img.width, img.height, RGB, "Paper #2", 100, LAYER_MODE_NORMAL)
		pdb.gimp_layer_add_alpha(paper2Layer)
		pdb.gimp_image_add_layer(img, paper2Layer, 1)
		pdb.gimp_context_set_foreground((217, 217, 217))
		pdb.gimp_drawable_fill(paper2Layer, FILL_FOREGROUND)	
		pdb.plug_in_hsv_noise(img, paper2Layer, 8, 3, 4, 75)
		pdb.plug_in_gauss(img, paper2Layer, 1.5, 1.5, 1)
		
		#Create paper 3 layer
		pdb.gimp_context_set_foreground((234, 234, 234))
		paper3Layer = pdb.gimp_layer_new(img, img.width, img.height, RGB, "Paper #3", 0, LAYER_MODE_NORMAL)
		pdb.gimp_layer_add_alpha(paper3Layer)
		pdb.gimp_image_add_layer(img, paper3Layer, 1)
		pdb.gimp_drawable_fill(paper3Layer, FILL_FOREGROUND)	
		pdb.plug_in_hsv_noise(img, paper3Layer, 8, 3, 4, 75)
		pdb.plug_in_gauss(img, paper3Layer, 1.5, 1.5, 1)
		
		#Make a selection on the text
		pdb.gimp_image_select_item(img, 2, textLayer)
		pdb.gimp_selection_grow(img, 12)
		pdb.gimp_context_set_foreground((0, 0, 0))
		pdb.gimp_edit_bucket_fill(textLayer, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)	
		pdb.gimp_layer_set_opacity(textLayer, 0)
		pdb.gimp_item_set_name(textLayer, "Text")
		
		#Create first cut
		pdb.gimp_image_select_item(img, 2, textLayer)
		pdb.gimp_selection_shrink(img, 25)
		paper2Layer = pdb.gimp_image_get_layer_by_name(img, "Paper #2")
		pdb.gimp_drawable_edit_clear(paper2Layer)
		pdb.gimp_selection_none(img)
		#Drop Shadow
		pdb.python_layerfx_drop_shadow(img, paper2Layer,
											("Black"),   #color
												  100,   #opacity
													0,   #contou - linear
													0,   #noise
													3,   #mode - multiply
												   40,   #spread
												   25,   #size
												  120,   #offset_angle
													5,   #offset_distance
												  TRUE,   #knockout
												 FALSE)   #merge
				
		#Create second cut
		#Stroke
		pdb.python_layerfx_stroke(img, textLayer, 
								 (234, 234, 234),    #color 
											   0,	 #opacity
											   0,	 #mode - normal
											 100,	 #size
											 100,	 #position
										   FALSE)	 #merge
		
		
		stroke = pdb.gimp_image_get_layer_by_name(img, "Text-stroke")
		pdb.gimp_image_select_item(img, 2, stroke)
		pdb.gimp_selection_shrink(img, 10)
		pdb.gimp_selection_feather(img, 35)
		pdb.gimp_selection_sharpen(img)
		pdb.gimp_drawable_edit_clear(paper3Layer)
		pdb.gimp_selection_none(img)
		
		#Drop Shadow
		pdb.python_layerfx_drop_shadow(img, paper3Layer,
											  ("Black"),   #color
													100,   #opacity
													  0,   #contou - linear
													  0,   #noise
													  3,   #mode - multiply
													 40,   #spread
													 25,   #size
													120,   #offset_angle
													  5,   #offset_distance
												   TRUE,   #knockout
												 FALSE)   #merge
				
		#Bevel and emboss
		pdb.python_layerfx_bevel_emboss(img, paper3Layer, 
														 1,   #style inner bevel
														65,   #depth 
														 0,   #direction 
														20,   #size 
														16,   #soften
													   120,   #angle 
														30,   #altitude 
														 0,   #gloss_contour - linear
												   "White",   #highlight_color 
														 5,   #highlight_mode lighten only
														75,   #highlight_opacity
												   "Black",   #shadow_color 
														 3,   #shadow_mode - multiply
														75,   #shadow_opacity 
														 0,   #surface_contour - linear
													 FALSE,   #use_texture 
											   "Dried mud",   #pattern 
													   100,   #scale 
													   100,   #tex_depth 
													 FALSE,   #invert 
													 FALSE)   #merge	
			
		#Bevel and emboss
		pdb.python_layerfx_bevel_emboss(img, textLayer, 
													 1,   #style inner bevel
													65,   #depth 
													 0,   #direction 
													20,   #size 
													16,   #soften
												   120,   #angle 
													30,   #altitude 
													 0,   #gloss_contour - linear
											   "White",   #highlight_color 
													 5,   #highlight_mode lighten only
													75,   #highlight_opacity
											   "Black",   #shadow_color 
													 3,   #shadow_mode - multiply
													75,   #shadow_opacity 
													 0,   #surface_contour - linear
												 FALSE,   #use_texture 
										   "Dried mud",   #pattern 
												   100,   #scale 
												   100,   #tex_depth 
												 FALSE,   #invert 
												 FALSE)   #merge
		
			
		#Create a copy from visible
		visiblelayer = pdb.gimp_layer_new_from_visible(img, img, "Visible")
		pdb.gimp_image_add_layer(img, visiblelayer, 0)
		pdb.gimp_layer_set_mode(visiblelayer, LAYER_MODE_OVERLAY)
					
		#Make the text chrome effect
		pdb.gimp_curves_spline(visiblelayer, 0, 8, (0, 0, 108, 255, 174, 0, 255, 255))
					
		#Make one layer and rename
		text = pdb.gimp_image_flatten(img)
		text = pdb.gimp_image_get_layer_by_name(img, "Paper #1")
		pdb.gimp_item_set_name(text, "Carved Chrome Text")
		
	#Set gimp to default
	pdb.gimp_context_set_defaults()
	pdb.gimp_context_set_default_colors()
	
register(
	"pm_carved_plastic_or_chrome_text",
	"Creates a carved plastic or chrome text",
	"Creates a carved plastic or shiny chrome text effect",
	"Pocholo",
	"Pocholo",
	"2020",
	"Carved Plastic or Steel Text",
	"",
[
	(PF_TEXT, "customtext", "Text string", 'GIMP\nEFFECT'),
	(PF_FONT, "fontname", "Font name", "HelveticaNeue Heavy"),
	(PF_BOOL, "plastic", "Plastic Text", False),
	(PF_BOOL, "chrome", "Chrome Text", False),
	(PF_SPINNER, "size", "Text size", 300, (300, 300, 1)),		
],
[],
pm_carved_plastic_or_chrome_text, menu="<Image>/Pocholo-scripts/Carved Plastic or Chrome Text")
main()		